@@ -708,15 +708,16 @@ class ANN():
             raise Exception("'file_name' must end with '.json'")
       
       
-        if include not in compat_include_params:
-
-            if type(include) == list or type(include) == tuple or type(include) == set:
-                for param in include:
-                    if param not in compat_include_params:
-                        raise Exception("compatible parameters for 'include' argement are: " + str(compat_include_params))
-              
-            else:
+        if type(include) == str:
+            if include not in compat_include_params:
                 raise Exception("compatible parameters for 'include' argement are: " + str(compat_include_params))
+
+        elif type(include) == list or type(include) == tuple or type(include) == set:
+            for param in include:
+                if param not in compat_include_params:
+                    raise Exception("compatible parameters for 'include' argement are: " + str(compat_include_params))
+        else:
+            raise Exception("compatible parameters for 'include' argement are: " + str(compat_include_params))
         
 
         model_json = {}
